@@ -32,6 +32,7 @@ from neuralspace.constants import (
     LANGUAGE,
     LANGUAGES,
     LAST_STATUS_UPDATED,
+    MESSAGE,
     METRICS,
     MODEL_ID,
     MODEL_NAME,
@@ -53,6 +54,7 @@ from neuralspace.constants import (
     START_INDEX,
     TEXT,
     TIMED_OUT,
+    TRAINING,
     TRAINING_STATUS,
     TRAINING_TIME,
     TYPE,
@@ -273,9 +275,9 @@ async def list_examples(
 ) -> Dict[Text, Any]:
     console.print(
         f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⬇️ Fetching Examples with filter: \n"
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] #️⃣ [bold]Project ID:[/bold] [orange]{project_id}[orange]"
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ✏️ Language: {language}; "
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🍲 Prepared: {prepared}; "
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] #️⃣ [bold]Project ID:[/bold] [orange]{project_id}[orange]\n"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ✏️ Language: {language}\n"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🍲 Prepared: {prepared}\n"
         f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 📌 type: {type}"
     )
     payload = {
@@ -312,6 +314,8 @@ async def list_examples(
 def get_training_status_colour(status: Text) -> Text:
     if status == COMPLETED:
         return C_COMPLETED
+    if status == TRAINING:
+        return C_COMPLETED
     elif status == FAILED:
         return C_FAILED
     elif status == TIMED_OUT:
@@ -335,10 +339,10 @@ def print_models_table(models: Dict[Text, Any], verbose: bool):
         table.add_column("Entity Acc")
         table.add_column("Training Time (sec)")
         table.add_column("Last Updated")
+        table.add_column("Training Message")
 
-    console.print(f"> Total Models Count: {models[DATA][COUNT]}")
     console.print(
-        f" [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Models Count: {models[DATA][COUNT]}"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Models Count: {models[DATA][COUNT]}"
     )
     for data in models[DATA][MODELS]:
         args = [data[MODEL_ID], data[MODEL_NAME]]
@@ -358,6 +362,7 @@ def print_models_table(models: Dict[Text, Any], verbose: bool):
                 if data[TRAINING_STATUS] == COMPLETED
                 else "0.0",
                 str(data[LAST_STATUS_UPDATED]),
+                data[MESSAGE],
             ]
         table.add_row(*args)
     console.print(table)
@@ -373,9 +378,9 @@ async def list_models(
 ) -> Dict[Text, Any]:
     console.print(
         f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⬇️ Fetching models with filter: \n"
-        f"#️⃣ Project ID: {project_id}; "
-        f"✏️ Language: {language}; "
-        f"🏋️ Training Statuses: {training_status}"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 👉️ Project ID: {project_id}\n"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗣️ Language: {language}\n"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🏋️ Training Statuses: {training_status}"
     )
     payload = {
         FILTER: {PROJECT_ID: project_id, LANGUAGE: language},
@@ -495,6 +500,7 @@ async def upload_dataset(
 async def wait_till_training_completes(
     model_id: Text, wait: bool, wait_interval: int
 ) -> Dict[Text, Any]:
+    json_response = None
     if wait:
         payload = {
             MODEL_ID: model_id,
@@ -502,8 +508,8 @@ async def wait_till_training_completes(
         HEADERS = copy(COMMON_HEADERS)
         HEADERS[AUTHORIZATION] = get_auth_token()
         console.print(
-            f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⏳ Waiting for training job to "
-            f"get trained for model id: {model_id}"
+            f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⏳ Waiting for model to "
+            f"get trained; model id: {model_id}"
         )
         current_status = ""
         with console.status("...") as status:
@@ -534,6 +540,11 @@ async def wait_till_training_completes(
                     status.update(f"Model is {current_status} 🧍")
                     await sleep(wait_interval)
                     status.update(f"Model is {current_status} 🏋")
+            console.print(
+                f"> [deep_sky_blue2]INFO[/deep_sky_blue2] "
+                f"{get_training_status_colour(json_response[DATA][TRAINING_STATUS])} "
+                f"Training status: {json_response[DATA][TRAINING_STATUS]}"
+            )
     return json_response
 
 
